==> mantik-0.2.0.tar.gz: mantik-0.2.0/src/tests/unit/tracking/test_track.py <==
import datetime
import os
import typing as t

import mantik.mlflow_server.flask.api as _api
import mantik.mlflow_server.tokens.cognito.exceptions as exceptions
import mantik.testing.env
import mantik.testing.token as testing_token
import mantik.tracking._server.tokens as _tokens
import mantik.tracking.track as track
import mantik.utils as utils


def test_track_without_existing_tokens(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    mlflow_tracking_uri,
    token_expiration_date,
):
    requests_mock.post(
        url=f"{mlflow_tracking_uri}{_api.tokens.CREATE_TOKEN_API_PATH}",
        json={
            "AccessToken": "test-access-token",
            "RefreshToken": "test-refresh-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-access-token",
    )
    # Cleanup
    os.unsetenv(utils.mlflow.TRACKING_TOKEN_ENV_VAR)


@testing_token.set_token(
    access_token="test-stored-access-token",
    refresh_token="test-stored-refresh-token",
)
def test_track_with_existing_valid_tokens(
    monkeypatch,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    mlflow_tracking_uri,
    token_expiration_date,
):
    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-stored-access-token",
    )


@testing_token.set_token(
    access_token="test-stored-expired-access-token",
    refresh_token="test-stored-refresh-token",
    expires_at=datetime.datetime(2020, 1, 1),
)
def test_track_with_existing_expired_token(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    mlflow_tracking_uri,
    token_expiration_date,
):
    requests_mock.post(
        url=f"{mlflow_tracking_uri}{_api.tokens.REFRESH_TOKEN_API_PATH}",
        json={
            "AccessToken": "test-refreshed-access-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-refreshed-access-token",
    )


@testing_token.set_token(
    access_token="test-stored-expired-access-token", refresh_token="test-stored"
)
def test_track_with_existing_expired_token_and_expired_refresh_token(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    mlflow_tracking_uri,
    token_expiration_date,
):
    # Mock refresh api to return expired error
    requests_mock.post(
        url=f"{mlflow_tracking_uri}{_api.tokens.REFRESH_TOKEN_API_PATH}",
        status_code=401,
        text=exceptions.REFRESH_TOKEN_EXPIRED_ERROR_MESSAGE,
    )
    # Mock get api to return refreshed tokens
    requests_mock.post(
        url=(f"{mlflow_tracking_uri}" f"{_api.tokens.CREATE_TOKEN_API_PATH}"),
        json={
            "AccessToken": "test-refreshed-access-token",
            "RefreshToken": "test-refreshed-refresh-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    tokens = _tokens.Tokens(
        access_token="test-stored-expired-access-token",
        refresh_token="test-stored-refresh-token",
        expires_at=datetime.datetime(2020, 1, 1),
    )
    tokens.write_to_file(track._MANTIK_TOKEN_FILE)

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-refreshed-access-token",
    )

    result_tokens = _tokens.Tokens.from_file(track._MANTIK_TOKEN_FILE)
    assert result_tokens.access_token == "test-refreshed-access-token"
    assert result_tokens.refresh_token == "test-refreshed-refresh-token"
    assert result_tokens.expires_at == token_expiration_date


@testing_token.set_token(
    access_token="test-stored-expired-access-token",
    refresh_token="test-stored-invalid-refresh-token",
    expires_at=datetime.datetime(2020, 1, 1),
)
def test_track_with_existing_invalid_refresh_token(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    mlflow_tracking_uri,
    token_expiration_date,
):
    # Mock refresh api to return invalid error
    requests_mock.post(
        url=f"{mlflow_tracking_uri}{_api.tokens.REFRESH_TOKEN_API_PATH}",
        status_code=401,
        text=exceptions.REFRESH_TOKEN_INVALID_ERROR_MESSAGE,
    )
    # Mock get api to return refreshed tokens
    requests_mock.post(
        url=(f"{mlflow_tracking_uri}" f"{_api.tokens.CREATE_TOKEN_API_PATH}"),
        json={
            "AccessToken": "test-refreshed-access-token",
            "RefreshToken": "test-refreshed-refresh-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-refreshed-access-token",
    )

    result_tokens = _tokens.Tokens.from_file(track._MANTIK_TOKEN_FILE)
    assert result_tokens.access_token == "test-refreshed-access-token"
    assert result_tokens.refresh_token == "test-refreshed-refresh-token"
    assert result_tokens.expires_at == token_expiration_date


def _init_tracking_and_assert_expected(
    env_vars: t.Dict[str, str],
    expected_access_token: str,
) -> None:
    with utils.env.env_vars_set(env_vars):
        track.init_tracking()

        mantik.testing.env.assert_conflicting_mlflow_env_vars_not_set()
        mantik.testing.env.assert_correct_tracking_token_env_var_set(
            expected_access_token
        )

==> mantik-0.3.1.tar.gz: mantik-0.3.1/src/tests/unit/tracking/test_track.py <==
import datetime
import os
import typing as t

import mantik.authentication.auth as auth
import mantik.authentication.tokens as _tokens
import mantik.mlflow_server.tokens.cognito.exceptions as exceptions
import mantik.testing.env
import mantik.testing.token as testing_token
import mantik.tracking.track as track
import mantik.utils as utils
import mantik.utils.mantik_api.client as mantik_api


def test_track_without_existing_tokens(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    token_expiration_date,
):
    requests_mock.post(
        url=f"{mantik_api.MANTIK_API_URL}"
        f"{mantik_api.MANTIK_API_CREATE_TOKEN_API_PATH}",
        json={
            "AccessToken": "test-access-token",
            "RefreshToken": "test-refresh-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-access-token",
    )
    # Cleanup
    os.unsetenv(utils.mlflow.TRACKING_TOKEN_ENV_VAR)


@testing_token.set_token(
    access_token="test-stored-access-token",
    refresh_token="test-stored-refresh-token",
)
def test_track_with_existing_valid_tokens(
    monkeypatch,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    token_expiration_date,
):
    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-stored-access-token",
    )


@testing_token.set_token(
    access_token="test-stored-expired-access-token",
    refresh_token="test-stored-refresh-token",
    expires_at=datetime.datetime(2020, 1, 1),
)
def test_track_with_existing_expired_token(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    token_expiration_date,
):
    requests_mock.post(
        url=f"{mantik_api.MANTIK_API_URL}"
        f"{mantik_api.MANTIK_API_REFRESH_TOKEN_API_PATH}",
        json={
            "AccessToken": "test-refreshed-access-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-refreshed-access-token",
    )


@testing_token.set_token(
    access_token="test-stored-expired-access-token", refresh_token="test-stored"
)
def test_track_with_existing_expired_token_and_expired_refresh_token(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    token_expiration_date,
):
    # Mock refresh api to return expired error
    requests_mock.post(
        url=f"{mantik_api.MANTIK_API_URL}"
        f"{mantik_api.MANTIK_API_REFRESH_TOKEN_API_PATH}",
        status_code=401,
        text=exceptions.REFRESH_TOKEN_EXPIRED_ERROR_MESSAGE,
    )
    # Mock get api to return refreshed tokens
    requests_mock.post(
        url=(
            f"{mantik_api.MANTIK_API_URL}"
            f"{mantik_api.MANTIK_API_CREATE_TOKEN_API_PATH}"
        ),
        json={
            "AccessToken": "test-refreshed-access-token",
            "RefreshToken": "test-refreshed-refresh-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    tokens = _tokens.Tokens(
        access_token="test-stored-expired-access-token",
        refresh_token="test-stored-refresh-token",
        expires_at=datetime.datetime(2020, 1, 1),
    )
    tokens.write_to_file(auth._MANTIK_TOKEN_FILE)

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-refreshed-access-token",
    )

    result_tokens = _tokens.Tokens.from_file(auth._MANTIK_TOKEN_FILE)
    assert result_tokens.access_token == "test-refreshed-access-token"
    assert result_tokens.refresh_token == "test-refreshed-refresh-token"
    assert result_tokens.expires_at == token_expiration_date


@testing_token.set_token(
    access_token="test-stored-expired-access-token",
    refresh_token="test-stored-invalid-refresh-token",
    expires_at=datetime.datetime(2020, 1, 1),
)
def test_track_with_existing_invalid_refresh_token(
    requests_mock,
    tmp_dir_as_test_mantik_folder,
    required_env_vars,
    token_expiration_date,
):
    # Mock refresh api to return invalid error
    requests_mock.post(
        url=f"{mantik_api.MANTIK_API_URL}"
        f"{mantik_api.MANTIK_API_REFRESH_TOKEN_API_PATH}",
        status_code=401,
        text=exceptions.REFRESH_TOKEN_INVALID_ERROR_MESSAGE,
    )
    # Mock get api to return refreshed tokens
    requests_mock.post(
        url=(
            f"{mantik_api.MANTIK_API_URL}"
            f"{mantik_api.MANTIK_API_CREATE_TOKEN_API_PATH}"
        ),
        json={
            "AccessToken": "test-refreshed-access-token",
            "RefreshToken": "test-refreshed-refresh-token",
            "ExpiresAt": token_expiration_date.isoformat(),
        },
    )

    _init_tracking_and_assert_expected(
        env_vars=required_env_vars,
        expected_access_token="test-refreshed-access-token",
    )

    result_tokens = _tokens.Tokens.from_file(auth._MANTIK_TOKEN_FILE)
    assert result_tokens.access_token == "test-refreshed-access-token"
    assert result_tokens.refresh_token == "test-refreshed-refresh-token"
    assert result_tokens.expires_at == token_expiration_date


def _init_tracking_and_assert_expected(
    env_vars: t.Dict[str, str],
    expected_access_token: str,
) -> None:
    with utils.env.env_vars_set(env_vars):
        track.init_tracking()

        mantik.testing.env.assert_conflicting_mlflow_env_vars_not_set()
        mantik.testing.env.assert_correct_tracking_token_env_var_set(
            expected_access_token
        )
